@@ -7,6 +7,8 @@ import numpy as np
 import nibabel as nib
 from nibabel.spatialimages import ImageFileError
 
+from .utils import verbose
+
 import logging
 logger = logging.getLogger('surfer')
 
@@ -128,6 +130,7 @@ def read_stc(filepath):
     return stc
 
 
+@verbose
 def project_volume_data(filepath, hemi, reg_file=None, subject_id=None,
                         projmeth="frac", projsum="avg", projarg=[0, 1, .1],
                         surf="white", smooth_fwhm=3, mask_label=None,
@@ -176,7 +179,9 @@ def project_volume_data(filepath, hemi, reg_file=None, subject_id=None,
         cmd = ['bash', '-c', 'source {} && env'.format(
                os.path.join(env['FREESURFER_HOME'], 'FreeSurferEnv.sh'))]
         envout = check_output(cmd)
-        env = dict(line.split('=', 1) for line in envout.split('\n') if line)
+        env = dict(line.split('=', 1)
+                   for line in envout.decode('utf-8').split('\n')
+                   if '=' in line)
 
     # Set the basic commands
     cmd_list = ["mri_vol2surf",
@@ -198,7 +203,7 @@ def project_volume_data(filepath, hemi, reg_file=None, subject_id=None,
         proj_flag += "-"
         proj_flag += projsum
     if hasattr(projarg, "__iter__"):
-        proj_arg = map(str, projarg)
+        proj_arg = list(map(str, projarg))
     else:
         proj_arg = [str(projarg)]
     cmd_list.extend([proj_flag] + proj_arg)
