@@ -1,18 +1,17 @@
-import numpy as np
 import os
 import os.path as op
 from os.path import join as pjoin
-import re
 import shutil
-import subprocess
-from nose.tools import assert_equal
-from numpy.testing import assert_raises, assert_array_equal
 from tempfile import mkdtemp, mktemp
+
+from nose.tools import assert_equal
+from mayavi import mlab
 import nibabel as nib
+import numpy as np
+from numpy.testing import assert_raises, assert_array_equal
 
 from surfer import Brain, io, utils
-from surfer.utils import requires_ffmpeg, requires_fsaverage
-from mayavi import mlab
+from surfer.utils import requires_fsaverage, requires_imageio
 
 subj_dir = utils._get_subjects_dir()
 subject_id = 'fsaverage'
@@ -34,10 +33,12 @@ requires_fs = np.testing.dec.skipif(not has_freesurfer(),
 
 @requires_fsaverage
 def test_offscreen():
-    """Test offscreen rendering
-    """
+    """Test offscreen rendering."""
     mlab.options.backend = 'auto'
     brain = Brain(*std_args, offscreen=True)
+    # Sometimes the first screenshot is rendered with a different
+    # resolution on OS X
+    brain.screenshot()
     shot = brain.screenshot()
     assert_array_equal(shot.shape, (800, 800, 3))
     brain.close()
@@ -45,8 +46,7 @@ def test_offscreen():
 
 @requires_fsaverage
 def test_image():
-    """Test image saving
-    """
+    """Test image saving."""
     tmp_name = mktemp() + '.png'
 
     mlab.options.backend = 'auto'
@@ -57,6 +57,7 @@ def test_image():
 
     brain = Brain(*std_args, size=100)
     brain.save_image(tmp_name)
+    brain.save_image(tmp_name, 'rgba', True)
     brain.save_montage(tmp_name, ['l', 'v', 'm'], orientation='v')
     brain.save_montage(tmp_name, ['l', 'v', 'm'], orientation='h')
     brain.save_montage(tmp_name, [['l', 'v'], ['m', 'f']])
@@ -66,26 +67,32 @@ def test_image():
 
 @requires_fsaverage
 def test_brains():
-    """Test plotting of Brain with different arguments
-    """
+    """Test plotting of Brain with different arguments."""
     # testing backend breaks when passing in a figure, so we use 'auto' here
     # (shouldn't affect usability, but it makes testing more annoying)
     mlab.options.backend = 'auto'
-    surfs = ['inflated', 'white']
-    hemis = ['lh', 'rh']
-    curvs = [True, False]
-    titles = [None, 'Hello']
-    cortices = ["low_contrast", ("Reds", 0, 1, False)]
-    sizes = [500, (400, 300)]
-    backgrounds = ["white", "blue"]
-    foregrounds = ["black", "white"]
-    figs = [None, mlab.figure()]
-    subj_dirs = [None, subj_dir]
-    for surf, hemi, curv, title, cort, s, bg, fg, fig, sd \
-            in zip(surfs, hemis, curvs, titles, cortices, sizes,
-                   backgrounds, foregrounds, figs, subj_dirs):
-        brain = Brain(subject_id, hemi, surf, curv, title,
-                      cort, s, bg, fg, fig, sd)
+    surfs = ['inflated', 'white', 'white', 'white', 'white', 'white', 'white']
+    hemis = ['lh', 'rh', 'both', 'both', 'rh', 'both', 'both']
+    titles = [None, 'Hello', 'Good bye!', 'lut test',
+              'dict test', 'None test', 'RGB test']
+    cortices = ["low_contrast", ("Reds", 0, 1, False), 'hotpink',
+                ['yellow', 'blue'], dict(colormap='Greys'),
+                None, (0.5, 0.5, 0.5)]
+    sizes = [500, (400, 300), (300, 300), (300, 400), 500, 400, 300]
+    backgrounds = ["white", "blue", "black", "0.75",
+                   (0.2, 0.2, 0.2), "black", "0.75"]
+    foregrounds = ["black", "white", "0.75", "red",
+                   (0.2, 0.2, 0.2), "blue", "black"]
+    figs = [None, mlab.figure(), None, None, mlab.figure(), None, None]
+    subj_dirs = [None, subj_dir, subj_dir, subj_dir,
+                 subj_dir, subj_dir, subj_dir]
+    alphas = [1.0, 0.5, 0.25, 0.7, 0.5, 0.25, 0.7]
+    for surf, hemi, title, cort, s, bg, fg, fig, sd, alpha \
+            in zip(surfs, hemis, titles, cortices, sizes,
+                   backgrounds, foregrounds, figs, subj_dirs, alphas):
+        brain = Brain(subject_id, hemi, surf, title=title, cortex=cort,
+                      alpha=alpha, size=s, background=bg, foreground=fg,
+                      figure=fig, subjects_dir=sd)
         brain.close()
     assert_raises(ValueError, Brain, subject_id, 'lh', 'inflated',
                   subjects_dir='')
@@ -93,8 +100,7 @@ def test_brains():
 
 @requires_fsaverage
 def test_annot():
-    """Test plotting of annot
-    """
+    """Test plotting of annot."""
     mlab.options.backend = 'test'
     annots = ['aparc', 'aparc.a2005s']
     borders = [True, False, 2]
@@ -108,8 +114,7 @@ def test_annot():
 
 @requires_fsaverage
 def test_contour():
-    """Test plotting of contour overlay
-    """
+    """Test plotting of contour overlay."""
     mlab.options.backend = 'test'
     brain = Brain(*std_args)
     overlay_file = pjoin(data_dir, "lh.sig.nii.gz")
@@ -124,21 +129,20 @@ def test_contour():
 @requires_fsaverage
 @requires_fs
 def test_data():
-    """Test plotting of data
-    """
+    """Test plotting of data."""
     mlab.options.backend = 'test'
     brain = Brain(*std_args)
     mri_file = pjoin(data_dir, 'resting_corr.nii.gz')
     reg_file = pjoin(data_dir, 'register.dat')
     surf_data = io.project_volume_data(mri_file, "lh", reg_file)
     brain.add_data(surf_data, -.7, .7, colormap="jet", alpha=.7)
+    brain.add_data([], vertices=np.array([], int))
     brain.close()
 
 
 @requires_fsaverage
 def test_foci():
-    """Test plotting of foci
-    """
+    """Test plotting of foci."""
     mlab.options.backend = 'test'
     brain = Brain(*std_args)
     coords = [[-36, 18, -3],
@@ -158,8 +162,7 @@ def test_foci():
 
 @requires_fsaverage
 def test_label():
-    """Test plotting of label
-    """
+    """Test plotting of label."""
     mlab.options.backend = 'test'
     subject_id = "fsaverage"
     hemi = "lh"
@@ -181,31 +184,39 @@ def test_label():
 
 @requires_fsaverage
 def test_meg_inverse():
-    """Test plotting of MEG inverse solution
-    """
+    """Test plotting of MEG inverse solution."""
     mlab.options.backend = 'test'
     brain = Brain(*std_args)
     stc_fname = os.path.join(data_dir, 'meg_source_estimate-lh.stc')
     stc = io.read_stc(stc_fname)
     data = stc['data']
     vertices = stc['vertices']
-    time = 1e3 * np.linspace(stc['tmin'],
-                             stc['tmin'] + data.shape[1] * stc['tstep'],
-                             data.shape[1])
+    time = np.linspace(stc['tmin'], stc['tmin'] + data.shape[1] * stc['tstep'],
+                       data.shape[1], endpoint=False)
     colormap = 'hot'
-    time_label = 'time=%0.2f ms'
+
+    def time_label(t):
+        return 'time=%0.2f ms' % (1e3 * t)
+
     brain.add_data(data, colormap=colormap, vertices=vertices,
                    smoothing_steps=10, time=time, time_label=time_label)
-    brain.set_data_time_index(2)
     brain.scale_data_colormap(fmin=13, fmid=18, fmax=22, transparent=True)
+    assert_equal(brain.data_dict['lh']['time_idx'], 0)
+
+    brain.set_time(.1)
+    assert_equal(brain.data_dict['lh']['time_idx'], 2)
     # viewer = TimeViewer(brain)
+
+    brain.add_data(data, colormap=colormap, vertices=vertices,
+                   smoothing_steps=10, time=time, time_label=time_label,
+                   initial_time=.09, remove_existing=True)
+    assert_equal(brain.data_dict['lh']['time_idx'], 1)
     brain.close()
 
 
 @requires_fsaverage
 def test_morphometry():
-    """Test plotting of morphometry
-    """
+    """Test plotting of morphometry."""
     mlab.options.backend = 'test'
     brain = Brain(*std_args)
     brain.add_morphometry("curv")
@@ -214,11 +225,12 @@ def test_morphometry():
     brain.close()
 
 
-@requires_ffmpeg
+@requires_imageio
 @requires_fsaverage
 def test_movie():
-    """Test saving a movie of an MEG inverse solution
-    """
+    """Test saving a movie of an MEG inverse solution."""
+    import imageio
+
     # create and setup the Brain instance
     mlab.options.backend = 'auto'
     brain = Brain(*std_args)
@@ -234,18 +246,16 @@ def test_movie():
     tempdir = mkdtemp()
     try:
         dst = os.path.join(tempdir, 'test.mov')
-        brain.save_movie(dst)
-        brain.save_movie(dst, tmin=0.081, tmax=0.102)
         # test the number of frames in the movie
-        sp = subprocess.Popen(('ffmpeg', '-i', 'test.mov', '-vcodec', 'copy',
-                               '-f', 'null', '/dev/null'), cwd=tempdir,
-                              stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        stdout, stderr = sp.communicate()
-        m = re.search('frame=\s*(\d+)\s', stderr)
-        if not m:
-            raise RuntimeError(stderr)
-        n_frames = int(m.group(1))
-        assert_equal(n_frames, 3)
+        brain.save_movie(dst)
+        frames = imageio.mimread(dst)
+        assert_equal(len(frames), 2)
+        brain.save_movie(dst, time_dilation=10)
+        frames = imageio.mimread(dst)
+        assert_equal(len(frames), 7)
+        brain.save_movie(dst, tmin=0.081, tmax=0.102)
+        frames = imageio.mimread(dst)
+        assert_equal(len(frames), 2)
     finally:
         # clean up
         shutil.rmtree(tempdir)
@@ -254,8 +264,7 @@ def test_movie():
 
 @requires_fsaverage
 def test_overlay():
-    """Test plotting of overlay
-    """
+    """Test plotting of overlay."""
     mlab.options.backend = 'test'
     # basic overlay support
     overlay_file = pjoin(data_dir, "lh.sig.nii.gz")
@@ -287,8 +296,7 @@ def test_overlay():
 
 @requires_fsaverage
 def test_probabilistic_labels():
-    """Test plotting of probabilistic labels
-    """
+    """Test plotting of probabilistic labels."""
     mlab.options.backend = 'test'
     brain = Brain("fsaverage", "lh", "inflated",
                   cortex="low_contrast")
@@ -313,8 +321,7 @@ def test_probabilistic_labels():
 
 @requires_fsaverage
 def test_text():
-    """Test plotting of text
-    """
+    """Test plotting of text."""
     mlab.options.backend = 'test'
     brain = Brain(*std_args)
     brain.add_text(0.1, 0.1, 'Hello', 'blah')
@@ -323,8 +330,7 @@ def test_text():
 
 @requires_fsaverage
 def test_animate():
-    """Test animation
-    """
+    """Test animation."""
     mlab.options.backend = 'auto'
     brain = Brain(*std_args, size=100)
     brain.add_morphometry('curv')
@@ -338,8 +344,7 @@ def test_animate():
 
 @requires_fsaverage
 def test_views():
-    """Test showing different views
-    """
+    """Test showing different views."""
     mlab.options.backend = 'test'
     brain = Brain(*std_args)
     brain.show_view('lateral')
